@@ -11,7 +11,7 @@ from tests.parquet_helper import ParquetHelper
 from tests.spark_test_helper import SparkTestHelper
 
 
-def test_can_load_parquet(spark_session: SparkSession):
+def test_can_load_parquet(spark_session: SparkSession) -> None:
     # Arrange
     SparkTestHelper.clear_tables(spark_session)
 
